From f84ba553ebaad5fb445d7baf5e21ca41d6c0849d Mon Sep 17 00:00:00 2001
From: HATAYAMA Daisuke <d.hatayama@jp.fujitsu.com>
Date: Tue, 13 Mar 2012 19:08:07 +0900
Subject: [PATCH 2/4] Add dump iomem/ioport functions

dump_iomem() displays /proc/iomem information, and and dump_ioport()
displays /proc/ioport information.

Both uses a helper function foreach_resource_tree() introduced in the
previous patch.

Signed-off-by: HATAYAMA Daisuke <d.hatayama@jp.fujitsu.com>
---
 memory.c |   26 ++++++++++++++++++++++++++
 1 files changed, 26 insertions(+), 0 deletions(-)

diff --git a/memory.c b/memory.c
index be2c540..a102c6b 100755
--- a/memory.c
+++ b/memory.c
@@ -250,6 +250,9 @@ static int verify_pfn(ulong);
 static void dump_per_cpu_offsets(void);
 static void dump_page_flags(ulonglong);
 static ulong kmem_cache_nodelists(ulong);
+static void print_resource_entry(struct resource_data *);
+static void dump_iomem(void);
+static void dump_ioport(void);
 
 /*
  *  Memory display modes specific to this file.
@@ -16337,3 +16340,26 @@ void foreach_resource_tree(ulong root, foreach_resource_function f)
 		p = sibling;
 	}
 }
+
+static void print_resource_entry(struct resource_data *r)
+{
+	fprintf(fp, "%*s%0*llx-%0*llx : %s\n",
+		r->depth * 2, "",
+		r->width, (unsigned long long) r->start,
+		r->width, (unsigned long long) r->end,
+		r->name ? r->name : "<BAD>");
+}
+
+static void
+dump_iomem(void)
+{
+	foreach_resource_tree(symbol_value("iomem_resource"),
+			      print_resource_entry);
+}
+
+static void
+dump_ioport(void)
+{
+	foreach_resource_tree(symbol_value("ioport_resource"),
+			      print_resource_entry);
+}
-- 
1.7.4.4

